@@ -1,5 +1,5 @@
 package Kephra::File::IO;
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 use strict;
 use warnings;
@@ -73,4 +73,11 @@ sub write_buffer {
 	}
 }
 
+
+sub get_age {
+	my $file = shift;
+	return unless -e $file;
+	return $^T - (-M $file) * 86400;
+}
+
 1;
